module.exports = defineTest({
	description: 'exported live bindings',
	options: {
		output: {
			name: 'iife'
		}
	}
});
